@@ -31,7 +31,7 @@ use DiaColloDB::Persistent;
 use DiaColloDB::Utils qw(:math :fcntl :json :sort :pack :regex :file :si :run :env :temp);
 #use DiaColloDB::Temp::Vec;
 use DiaColloDB::Timer;
-use DDC::XS; ##-- for query parsing
+use DDC::Any; ##-- for query parsing
 use Fcntl;
 use File::Path qw(make_path remove_tree);
 use version;
@@ -41,7 +41,7 @@ use strict;
 ##==============================================================================
 ## Globals & Constants
 
-our $VERSION = "0.10.004_03";
+our $VERSION = "0.10.005";
 our @ISA = qw(DiaColloDB::Client);
 
 ## $PGOOD_DEFAULT
@@ -137,7 +137,6 @@ our %TDF_OPTS = (
 ##    tfmin => $tfmin,    ##-- minimum global term-frequency WITHOUT date component (default=2)
 ##    fmin_${a} => $fmin, ##-- minimum independent frequency for value of attribute ${a} (default=undef:from $tfmin)
 ##    keeptmp => $bool,   ##-- keep temporary files? (default=0)
-##    mmap => $bool,      ##-- use mmap() subclasses if available? (default: true)
 ##    index_tdf => $bool, ##-- tdf: create/use (term x document) frequency matrix index? (default=undef: if available)
 ##    index_cof => $bool, ##-- cof: create/use co-frequency index (default=1)
 ##    index_xf => $bool,  ##-- xf: create/use unigram index (default=1)
@@ -213,7 +212,6 @@ sub new {
 		      cfmin => 2,
 		      tfmin => 2,
 		      #keeptmp => 0,
-		      #mmap => 1,
 		      index_tdf => undef,
 		      index_cof => 1,
 		      index_xf => 1,
@@ -366,20 +364,20 @@ sub open {
   foreach my $attr (@$attrs) {
     ##-- open: ${attr}*
     my $abase = (-r "$dbdir/${attr}_enum.hdr" ? "$dbdir/${attr}_" : "$dbdir/${attr}"); ##-- v0.03-compatibility hack
-    $coldb->{"${attr}enum"} = $coldb->mmclass($ECLASS)->new(base=>"${abase}enum", %efopts)
+    $coldb->{"${attr}enum"} = $ECLASS->new(base=>"${abase}enum", %efopts)
       or $coldb->logconfess("open(): failed to open enum ${abase}enum.*: $!");
-    $coldb->{"${attr}2t"} = $coldb->mmclass($MMCLASS)->new(base=>"${abase}2t", %mmopts)
+    $coldb->{"${attr}2t"} = $MMCLASS->new(base=>"${abase}2t", %mmopts)
       or $coldb->logconfess("open(): failed to open expansion multimap ${abase}2x.*: $!");
     $coldb->{"pack_t$attr"} //= "\@${atat}$coldb->{pack_id}";
     $atat += packsize($coldb->{pack_id});
   }
 
   ##-- open: tenum
-  $coldb->{tenum} = $coldb->mmclass($XECLASS)->new(base=>"$dbdir/tenum", %efopts, pack_s=>$coldb->{pack_t})
+  $coldb->{tenum} = $XECLASS->new(base=>"$dbdir/tenum", %efopts, pack_s=>$coldb->{pack_t})
       or $coldb->logconfess("open(): failed to open tuple-enum $dbdir/tenum.*: $!");
 
   ##-- open: xf
-  $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags, mmap=>$coldb->{mmap},
+  $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags,
 						     pack_i=>$coldb->{pack_id}, pack_f=>$coldb->{pack_f}, pack_d=>$coldb->{pack_date}
 						    )
     or $coldb->logconfess("open(): failed to open tuple-unigrams $dbdir/xf.*: $!");
@@ -387,7 +385,7 @@ sub open {
 
   ##-- open: cof
   if ($coldb->{index_cof}//1) {
-    $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags, mmap=>$coldb->{mmap},
+    $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags,
 						       pack_i=>$coldb->{pack_id}, pack_f=>$coldb->{pack_f}, pack_d=>$coldb->{pack_date},
 						       dmax=>$coldb->{dmax}, fmin=>$coldb->{cfmin},
 						      )
@@ -488,7 +486,7 @@ sub create_multimap {
   }
   $_ = pack($pack_mmb, sort {$a<=>$b} unpack($pack_mmb,$_//'')) foreach (@v2ti); ##-- ensure multimap target-sets are sorted
 
-  my $v2t = $coldb->mmclass($MMCLASS)->new(base=>$base, flags=>'rw', perms=>$coldb->{perms}, pack_i=>$pack_id, pack_o=>$coldb->{pack_off}, pack_l=>$coldb->{pack_id})
+  my $v2t = $MMCLASS->new(base=>$base, flags=>'rw', perms=>$coldb->{perms}, pack_i=>$pack_id, pack_o=>$coldb->{pack_off}, pack_l=>$coldb->{pack_id})
     or $coldb->logconfess("create_multimap(): failed to create $base.*: $!");
   $v2t->fromArray(\@v2ti)
     or $coldb->logconfess("create_multimap(): failed to populate $base.*: $!");
@@ -541,8 +539,8 @@ BEGIN {
 		 'p'=>'pos',
 		);
   %ATTR_CBEXPR = (
-		  'doc.textClass' => DDC::XS::CQCountKeyExprRegex->new(DDC::XS::CQCountKeyExprBibl->new('textClass'),':.*$',''),
-		  'doc.genre'     => DDC::XS::CQCountKeyExprRegex->new(DDC::XS::CQCountKeyExprBibl->new('textClass'),':.*$',''),
+		  'doc.textClass' => DDC::Any::CQCountKeyExprRegex->new(DDC::Any::CQCountKeyExprBibl->new('textClass'),':.*$',''),
+		  'doc.genre'     => DDC::Any::CQCountKeyExprRegex->new(DDC::Any::CQCountKeyExprBibl->new('textClass'),':.*$',''),
 		 );
 }
 sub attrName {
@@ -570,10 +568,10 @@ sub attrCountBy {
   }
   if ($attr =~ /^doc\.(.*)$/) {
     ##-- document attribute ("doc.ATTR" convention)
-    return DDC::XS::CQCountKeyExprBibl->new($1);
+    return DDC::Any::CQCountKeyExprBibl->new($1);
   } else {
     ##-- token attribute
-    return DDC::XS::CQCountKeyExprToken->new($attr, ($matchid||0), 0);
+    return DDC::Any::CQCountKeyExprToken->new($attr, ($matchid||0), 0);
   }
 }
 
@@ -666,7 +664,7 @@ sub create {
   my ($attr,$ac);
   foreach (0..$#$attrs) {
     push(@$aconf,$ac={i=>$_, a=>($attr=$attrs->[$_])});
-    $ac->{enum}   = $coldb->{"${attr}enum"} = $coldb->mmclass($ECLASS)->new(%efopts);
+    $ac->{enum}   = $coldb->{"${attr}enum"} = $ECLASS->new(%efopts);
     $ac->{pack_t} = $coldb->{"pack_t$attr"} = '@'.$axpos.$pack_id;
     $ac->{s2i}    = $ac->{enum}{s2i};
     $ac->{ma}     = $1 if ($attr =~ /^(?:meta|doc)\.(.*)$/);
@@ -676,7 +674,7 @@ sub create {
   my @aconfw = grep {!defined($_->{ma})} @$aconf; ##-- token-attributes
 
   ##-- initialize: tuple enum (+dates)
-  my $tenum = $coldb->{tenum} = $coldb->mmclass($XECLASS)->new(%efopts, pack_s=>$pack_t);
+  my $tenum = $coldb->{tenum} = $XECLASS->new(%efopts, pack_s=>$pack_t);
   my $ts2i  = $tenum->{s2i};
   my $nt    = 0;
 
@@ -913,16 +911,16 @@ sub create {
       if ($toki_in == $docoff_in) {
 	##-- update break-indices for tdf
 
-	##-- BUGHUNT/Birmingham: weird errors around here: Tue, 05 Jul 2016 09:27:11 +0200
-	$coldb->logconfess("create(): \$doci_cur not defined at \$atokfh line ", $atokfh->input_line_number)
-	  if (!defined($doci_cur));
-	$coldb->logconfess("create(): \$toki_out not defined at \$atokfh line ", $atokfh->input_line_number)
-	  if (!defined($toki_out));
-	$coldb->logconfess("create(): \$docoff->[\$doci_cur=$doci_cur] not defined at \$atokfh line ", $atokfh->input_line_number)
-	  if (!defined($docoff->[$doci_cur]));
-	$coldb->logconfess("create(): next \$docoff_in=\$docoff->[++(\$doci_cur=$doci_cur)] not defined at \$atokfh line ", $atokfh->input_line_number)
-	  if (!defined($docoff->[$doci_cur+1]));
-	##--/BUGHUNT
+#	##-- BUGHUNT/Birmingham: weird errors around here: Tue, 05 Jul 2016 09:27:11 +0200
+#	$coldb->logconfess("create(): \$doci_cur not defined at \$atokfh line ", $atokfh->input_line_number)
+#	  if (!defined($doci_cur));
+#	$coldb->logconfess("create(): \$toki_out not defined at \$atokfh line ", $atokfh->input_line_number)
+#	  if (!defined($toki_out));
+#	$coldb->logconfess("create(): \$docoff->[\$doci_cur=$doci_cur] not defined at \$atokfh line ", $atokfh->input_line_number)
+#	  if (!defined($docoff->[$doci_cur]));
+#	$coldb->logconfess("create(): next \$docoff_in=\$docoff->[++(\$doci_cur=$doci_cur)] not defined at \$atokfh line ", $atokfh->input_line_number)
+#	  if (!defined($docoff->[$doci_cur+1]));
+#	##--/BUGHUNT
 
 	$docoff->[$doci_cur] = $toki_out;
 	$docoff_in = $docoff->[++$doci_cur];
@@ -986,8 +984,7 @@ sub create {
   ##-- compute unigrams
   if ($coldb->{index_xf}//1) {
     $coldb->info("creating unigram index $dbdir/xf.*");
-    my $xfdb = $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags, mmap=>$coldb->{mmap},
-								  pack_i=>$pack_id, pack_f=>$pack_f, pack_d=>$pack_date)
+    my $xfdb = $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags, pack_i=>$pack_id, pack_f=>$pack_f, pack_d=>$pack_date)
       or $coldb->logconfess("create(): could not create $dbdir/xf.*: $!");
     $xfdb->create($coldb, $tokfile)
       or $coldb->logconfess("create(): failed to create unigram index: $!");
@@ -998,7 +995,7 @@ sub create {
   ##-- compute collocation frequencies
   if ($coldb->{index_cof}//1) {
     $coldb->info("creating co-frequency index $dbdir/cof.* [dmax=$coldb->{dmax}, fmin=$coldb->{cfmin}]");
-    my $cof = $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags, mmap=>$coldb->{mmap},
+    my $cof = $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags,
 								 pack_i=>$pack_id, pack_f=>$pack_f, pack_d=>$pack_date,
 								 dmax=>$coldb->{dmax}, fmin=>$coldb->{cfmin},
 								 keeptmp=>$coldb->{keeptmp},
@@ -1128,7 +1125,7 @@ sub union {
   foreach $ac (@$adata) {
     $coldb->vlog($coldb->{logCreate}, "union(): creating attribute enum $dbdir/$ac->{a}_enum.*");
     $attr  = $ac->{a};
-    $aenum = $coldb->{"${attr}enum"} = $ac->{enum} = $coldb->mmclass($ECLASS)->new(%efopts);
+    $aenum = $coldb->{"${attr}enum"} = $ac->{enum} = $ECLASS->new(%efopts);
     $as2i  = $aenum->{s2i};
     foreach $argi (0..$#dbargs) {
       ##-- enum union: guts
@@ -1159,7 +1156,7 @@ sub union {
 
   ##-- union: tenum
   $coldb->vlog($coldb->{logCreate}, "union(): creating tuple-enum $dbdir/tenum.*");
-  my $tenum = $coldb->{tenum} = $coldb->mmclass($XECLASS)->new(%efopts, pack_s=>$pack_t);
+  my $tenum = $coldb->{tenum} = $XECLASS->new(%efopts, pack_s=>$pack_t);
   my $ts2i  = $tenum->{s2i};
   my $nt    = 0;
   foreach $db (@dbargs) {
@@ -1202,7 +1199,7 @@ sub union {
   ##-- unigrams: populate
   if ($coldb->{index_xf}//1) {
     $coldb->vlog($coldb->{logCreate}, "union(): creating tuple unigram index $dbdir/xf.*");
-    $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags, mmap=>$coldb->{mmap},
+    $coldb->{xf} = DiaColloDB::Relation::Unigrams->new(base=>"$dbdir/xf", flags=>$flags,
 						       pack_i=>$pack_id, pack_f=>$pack_f, pack_d=>$pack_date,
 						       keeptmp => $coldb->{keeptmp},
 						      )
@@ -1216,7 +1213,7 @@ sub union {
   ##-- co-frequencies: populate
   if ($coldb->{index_cof}//1) {
     $coldb->vlog($coldb->{logCreate}, "union(): creating co-frequency index $dbdir/cof.* [fmin=$coldb->{cfmin}]");
-    $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags, mmap=>$coldb->{mmap},
+    $coldb->{cof} = DiaColloDB::Relation::Cofreqs->new(base=>"$dbdir/cof", flags=>$flags,
 						       pack_i=>$pack_id, pack_f=>$pack_f, pack_d=>$pack_date,
 						       dmax=>$coldb->{dmax}, fmin=>$coldb->{cfmin},
 						       keeptmp=>$coldb->{keeptmp},
@@ -1574,7 +1571,7 @@ sub relations {
 ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ## \@ids = $coldb->enumIds($enum,$req,%opts)
 ##  + parses enum IDs for $req, which is one of:
-##    - a DDC::XS::CQTokExact, ::CQTokInfl, ::CQTokSet, ::CQTokSetInfl, or ::CQTokRegex : interpreted
+##    - a DDC::Any::CQTokExact, ::CQTokInfl, ::CQTokSet, ::CQTokSetInfl, or ::CQTokRegex : interpreted
 ##    - an ARRAY-ref     : list of literal symbol-values
 ##    - a Regexp ref     : regexp for target strings, passed to $enum->re2i()
 ##    - a string /REGEX/ : regexp for target strings, passed to $enum->re2i()
@@ -1585,22 +1582,22 @@ sub relations {
 sub enumIds {
   my ($coldb,$enum,$req,%opts) = @_;
   $opts{logPrefix} //= "enumIds(): fetch ids";
-  if (UNIVERSAL::isa($req,'DDC::XS::CQTokInfl') || UNIVERSAL::isa($req,'DDC::XS::CQTokExact')) {
+  if (UNIVERSAL::isa($req,'DDC::Any::CQTokInfl') || UNIVERSAL::isa($req,'DDC::Any::CQTokExact')) {
     ##-- CQuery: CQTokExact
     $coldb->vlog($opts{logLevel}, $opts{logPrefix}, " (", ref($req), ")");
     return [$enum->s2i($req->getValue)];
   }
-  elsif (UNIVERSAL::isa($req,'DDC::XS::CQTokSet') || UNIVERSAL::isa($req,'DDC::XS::CQTokSetInfl')) {
+  elsif (UNIVERSAL::isa($req,'DDC::Any::CQTokSet') || UNIVERSAL::isa($req,'DDC::Any::CQTokSetInfl')) {
     ##-- CQuery: CQTokSet
     $coldb->vlog($opts{logLevel}, $opts{logPrefix}, " (", ref($req), ")");
     return [map {$enum->s2i($_)} @{$req->getValues}];
   }
-  elsif (UNIVERSAL::isa($req,'DDC::XS::CQTokRegex')) {
+  elsif (UNIVERSAL::isa($req,'DDC::Any::CQTokRegex')) {
     ##-- CQuery: CQTokRegex
     $coldb->vlog($opts{logLevel}, $opts{logPrefix}, " (", ref($req), ")");
     return $enum->re2i($req->getValue);
   }
-  elsif (UNIVERSAL::isa($req,'DDC::XS::CQTokAny')) {
+  elsif (UNIVERSAL::isa($req,'DDC::Any::CQTokAny')) {
     $coldb->vlog($opts{logLevel}, $opts{logPrefix}, " (", ref($req), ")");
     return undef;
   }
@@ -1689,9 +1686,9 @@ sub parseDateRequest {
 
 ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ## $compiler = $coldb->qcompiler();
-##  + get DDC::XS::CQueryCompiler for this object (cached in $coldb->{_qcompiler})
+##  + get DDC::Any::CQueryCompiler for this object (cached in $coldb->{_qcompiler})
 sub qcompiler {
-  return $_[0]{_qcompiler} ||= DDC::XS::CQueryCompiler->new();
+  return $_[0]{_qcompiler} ||= DDC::Any::CQueryCompiler->new();
 }
 
 ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -1716,7 +1713,7 @@ sub qparse {
 ## $cquery = $coldb->parseQuery("$attr1=$val1, ...", %opts)  ##-- compat: string
 ## $cquery = $coldb->parseQuery($ddcQueryString, %opts)      ##-- ddc string (with shorthand ","->WITH, "&&"->WITH)
 ##  + guts for parsing user target and groupby requests
-##  + returns a DDC::XS::CQuery object representing the request
+##  + returns a DDC::Any::CQuery object representing the request
 ##  + index-only items "$l" are mapped to $l=@{}
 ##  + %opts:
 ##     warn  => $level,       ##-- log-level for unknown attributes (default: 'warn')
@@ -1783,20 +1780,20 @@ sub parseQuery {
 
       #$coldb->debug("parseQuery($logas): parsing native request: (".($attr//'')." = ".($areq//''));
 
-      if (UNIVERSAL::isa($areq,'DDC::XS::CQuery')) {
+      if (UNIVERSAL::isa($areq,'DDC::Any::CQuery')) {
 	##-- compat: value: ddc query object
 	$aq = $areq;
 	$aq->setIndexName($attr) if ($aq->can('setIndexName') && $attr ne '');
       }
       elsif (UNIVERSAL::isa($areq,'ARRAY')) {
 	##-- compat: value: array --> CQTokSet @{VAL1,...,VALN}
-	$aq = DDC::XS::CQTokSet->new($attr, '', $areq);
+	$aq = DDC::Any::CQTokSet->new($attr, '', $areq);
       }
       elsif (UNIVERSAL::isa($areq,'RegExp') || (!$opts{ddcmode} && $areq && $areq =~ m{^${regre}$})) {
 	##-- compat: value: regex --> CQTokRegex /REGEX/
 	my $re = regex($areq)."";
 	$re    =~ s{^\(\?\^\:(.*)\)$}{$1};
-	$aq = DDC::XS::CQTokRegex->new($attr, $re);
+	$aq = DDC::Any::CQTokRegex->new($attr, $re);
       }
       elsif ($opts{ddcmode} && ($areq//'') ne '') {
 	##-- compat: ddcmode: parse requests as ddc queries
@@ -1809,12 +1806,12 @@ sub parseQuery {
 	my $vals = [grep {($_//'') ne ''} map {s{\\(.)}{$1}g; $_} split(/(?:(?<!\\)[\,\s\|])+/,($areq//''))];
 	$aq = (@$vals<=1
 	       ? (($vals->[0]//'*') eq '*'
-		  ? DDC::XS::CQTokAny->new($attr,'*')
-		  : DDC::XS::CQTokExact->new($attr,$vals->[0]))
-	       : DDC::XS::CQTokSet->new($attr,($areq//''),$vals));
+		  ? DDC::Any::CQTokAny->new($attr,'*')
+		  : DDC::Any::CQTokExact->new($attr,$vals->[0]))
+	       : DDC::Any::CQTokSet->new($attr,($areq//''),$vals));
       }
       ##-- push request to query
-      $q = $q ? DDC::XS::CQWith->new($q,$aq) : $aq;
+      $q = $q ? DDC::Any::CQWith->new($q,$aq) : $aq;
     }
   }
   else {
@@ -1850,7 +1847,7 @@ sub parseQuery {
 
   ##-- tweak query: map CQAnd to CQWith
   $q = $q->mapTraverse(sub {
-			 return UNIVERSAL::isa($_[0],'DDC::XS::CQAnd') ? DDC::XS::CQWith->new($_[0]->getDtr1,$_[0]->getDtr2) : $_[0];
+			 return UNIVERSAL::isa($_[0],'DDC::Any::CQAnd') ? DDC::Any::CQWith->new($_[0]->getDtr1,$_[0]->getDtr2) : $_[0];
 		       })
     if ($opts{mapand} || (!defined($opts{mapand}) && $req0 !~ /\&\&/));
 
@@ -1889,73 +1886,73 @@ sub queryAttributes {
       ##-- NULL: ignore
       next;
     }
-    elsif ($q->isa('DDC::XS::CQWith')) {
+    elsif ($q->isa('DDC::Any::CQWith')) {
       ##-- CQWith: ignore (just recurse)
       next;
     }
-    elsif ($q->isa('DDC::XS::CQueryOptions')) {
+    elsif ($q->isa('DDC::Any::CQueryOptions')) {
       ##-- CQueryOptions: check for nontrivial user requests
       $warnsub->("#WITHIN clause") if (@{$q->getWithin});
       $warnsub->("#CNTXT clause") if ($q->getContextSentencesCount);
     }
-    elsif ($q->isa('DDC::XS::CQToken')) {
+    elsif ($q->isa('DDC::Any::CQToken')) {
       ##-- CQToken: create attribute clause
       $warnsub->("negated query clause in native $logas request (".$q->toString.")") if ($q->getNegated);
       $warnsub->("explicit term-expansion chain in native $logas request (".$q->toString.")") if ($q->can('getExpanders') && @{$q->getExpanders});
 
       my $attr = $q->getIndexName || $default;
-      if (ref($q) =~ /^DDC::XS::CQTok(?:Exact|Set|Regex|Any)$/) {
+      if (ref($q) =~ /^DDC::\w+::CQTok(?:Exact|Set|Regex|Any)$/) {
 	$aq = $q;
-      } elsif (ref($q) eq 'DDC::XS::CQTokInfl') {
-	$aq = DDC::XS::CQTokExact->new($q->getIndexName, $q->getValue);
-      } elsif (ref($q) eq 'DDC::XS::CQTokSetInfl') {
-	$aq = DDC::XS::CQTokSet->new($q->getIndexName, $q->getValue, $q->getValues);
-      } elsif (ref($q) eq 'DDC::XS::CQTokPrefix') {
-	$aq = DDC::XS::CQTokRegex->new($q->getIndexName, '^'.quotemeta($q->getValue));
-      } elsif (ref($q) eq 'DDC::XS::CQTokSuffix') {
-	$aq = DDC::XS::CQTokRegex->new($q->getIndexName, quotemeta($q->getValue).'$');
-      } elsif (ref($q) eq 'DDC::XS::CQTokInfix') {
-	$aq = DDC::XS::CQTokRegex->new($q->getIndexName, quotemeta($q->getValue));
+      } elsif (ref($q) =~ /^DDC::\w+::CQTokInfl$/) {
+	$aq = DDC::Any::CQTokExact->new($q->getIndexName, $q->getValue);
+      } elsif (ref($q) =~ /^DDC::\w+::CQTokSetInfl$/) {
+	$aq = DDC::Any::CQTokSet->new($q->getIndexName, $q->getValue, $q->getValues);
+      } elsif (ref($q) =~ /^DDC::\w+::CQTokPrefix$/) {
+	$aq = DDC::Any::CQTokRegex->new($q->getIndexName, '^'.quotemeta($q->getValue));
+      } elsif (ref($q) =~ /^DDC::\w+::CQTokSuffix$/) {
+	$aq = DDC::Any::CQTokRegex->new($q->getIndexName, quotemeta($q->getValue).'$');
+      } elsif (ref($q) =~ /^DDC::\w+::CQTokInfix$/) {
+	$aq = DDC::Any::CQTokRegex->new($q->getIndexName, quotemeta($q->getValue));
       } else {
 	$warnsub->("token query clause of type ".ref($q)." in native $logas request (".$q->toString.")");
       }
-      $aq=undef if ($aq && $aq->isa('DDC::XS::CQTokAny')); ##-- empty value, e.g. for groupby
+      $aq=undef if ($aq && $aq->isa('DDC::Any::CQTokAny')); ##-- empty value, e.g. for groupby
       push(@$areqs, [$attr,$aq]);
     }
-    elsif ($q->isa('DDC::XS::CQFilter')) {
+    elsif ($q->isa('DDC::Any::CQFilter')) {
       ##-- CQFilter
-      if ($q->isa('DDC::XS::CQFHasField')) {
+      if ($q->isa('DDC::Any::CQFHasField')) {
 	##-- CQFilter: CQFHasField
 	my $attr = $q->getArg0;
-	if ($q->isa('DDC::XS::CQFHasFieldValue')) {
-	  $aq = DDC::XS::CQTokExact->new($attr, $q->getArg1);
+	if ($q->isa('DDC::Any::CQFHasFieldValue')) {
+	  $aq = DDC::Any::CQTokExact->new($attr, $q->getArg1);
 	}
-	elsif ($q->isa('DDC::XS::CQFHasFieldSet')) {
-	  $aq = DDC::XS::CQTokSet->new($attr, $q->getArg1, $q->getValues);
+	elsif ($q->isa('DDC::Any::CQFHasFieldSet')) {
+	  $aq = DDC::Any::CQTokSet->new($attr, $q->getArg1, $q->getValues);
 	}
-	elsif ($q->isa('DDC::XS::CQFHasFieldRegex')) {
-	  $aq = DDC::XS::CQTokRegex->new($attr, $q->getArg1);
+	elsif ($q->isa('DDC::Any::CQFHasFieldRegex')) {
+	  $aq = DDC::Any::CQTokRegex->new($attr, $q->getArg1);
 	}
-	elsif ($q->isa('DDC::XS::CQFHasFieldPrefix')) {
-	  $aq = DDC::XS::CQTokRegex->new($attr, '^'.quotemeta($q->getArg1));
+	elsif ($q->isa('DDC::Any::CQFHasFieldPrefix')) {
+	  $aq = DDC::Any::CQTokRegex->new($attr, '^'.quotemeta($q->getArg1));
 	}
-	elsif ($q->isa('DDC::XS::CQFHasFieldSuffix')) {
-	  $aq = DDC::XS::CQTokRegex->new($attr, quotemeta($q->getArg1).'$');
+	elsif ($q->isa('DDC::Any::CQFHasFieldSuffix')) {
+	  $aq = DDC::Any::CQTokRegex->new($attr, quotemeta($q->getArg1).'$');
 	}
-	elsif ($q->isa('DDC::XS::CQFHasFieldInfix')) {
-	  $aq = DDC::XS::CQTokRegex->new($attr, quotemeta($q->getArg1));
+	elsif ($q->isa('DDC::Any::CQFHasFieldInfix')) {
+	  $aq = DDC::Any::CQTokRegex->new($attr, quotemeta($q->getArg1));
 	}
 	else {
 	  $warnsub->("filter of type ".ref($q)." unsupported in native $logas request (".$q->toString.")");
 	}
-	$aq=undef if ($aq && $aq->isa('DDC::XS::CQTokAny')); ##-- empty value, e.g. for groupby
+	$aq=undef if ($aq && $aq->isa('DDC::Any::CQTokAny')); ##-- empty value, e.g. for groupby
 	push(@$areqs, [$attr,$aq]);
       }
-      elsif ($q->isa('DDC::XS::CQFRandomSort') || $q->isa('DDC::XS::CQFRankSort')) {
+      elsif ($q->isa('DDC::Any::CQFRandomSort') || $q->isa('DDC::Any::CQFRankSort')) {
 	##-- CQFilter: CQFRandomSort, CQFRanksort: ignore
 	next;
       }
-      elsif ($q->isa('DDC::XS::CQFSort') && ($q->getArg1 ne '' || $q->getArg2 ne '')) {
+      elsif ($q->isa('DDC::Any::CQFSort') && ($q->getArg1 ne '' || $q->getArg2 ne '')) {
 	##-- CQFilter: CQFSort: other
 	$warnsub->("filter of type ".ref($q)." with nontrivial bounds in native $logas request (".$q->toString.")");
       }
@@ -2042,7 +2039,7 @@ sub groupby {
   my ($ids);
   my @gbids  = (
 		map {
-		  ($_->[1] && !UNIVERSAL::isa($_->[1],'DDC::XS::CQTokAny')
+		  ($_->[1] && !UNIVERSAL::isa($_->[1],'DDC::Any::CQTokAny')
 		   ? {
 		      map {($_=>undef)}
 		      @{$coldb->enumIds($coldb->{"$_->[0]enum"}, $_->[1], logLevel=>$coldb->{logProfile}, logPrefix=>"groupby(): fetch filter ids: $_->[0]")}
@@ -2123,20 +2120,20 @@ sub query2filter {
   ##-- document attribute ("doc.ATTR" convention)
   my $field = $coldb->attrName( $attr // $q->getIndexName );
   $field = $1 if ($field =~ /^doc\.(.*)$/);
-  if (UNIVERSAL::isa($q, 'DDC::XS::CQTokAny')) {
+  if (UNIVERSAL::isa($q, 'DDC::Any::CQTokAny')) {
     return undef;
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokExact') || UNIVERSAL::isa($q, 'DDC::XS::CQTokInfl')) {
-    return DDC::XS::CQFHasField->new($field, $q->getValue, $q->getNegated);
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokSet') || UNIVERSAL::isa($q, 'DDC::XS::CQTokSetInfl')) {
-    return DDC::XS::CQFHasFieldSet->new($field, $q->getValues, $q->getNegated);
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokRegex')) {
-    return DDC::XS::CQFHasFieldRegex->new($field, $q->getValue, $q->getNegated);
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokPrefix')) {
-    return DDC::XS::CQFHasFieldPrefix->new($field, $q->getValue, $q->getNegated);
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokSuffix')) {
-    return DDC::XS::CQFHasFieldSuffix->new($field, $q->getValue, $q->getNegated);
-  } elsif (UNIVERSAL::isa($q, 'DDC::XS::CQTokInfix')) {
-    return DDC::XS::CQFHasFieldInfix->new($field, $q->getValue, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokExact') || UNIVERSAL::isa($q, 'DDC::Any::CQTokInfl')) {
+    return DDC::Any::CQFHasField->new($field, $q->getValue, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokSet') || UNIVERSAL::isa($q, 'DDC::Any::CQTokSetInfl')) {
+    return DDC::Any::CQFHasFieldSet->new($field, $q->getValues, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokRegex')) {
+    return DDC::Any::CQFHasFieldRegex->new($field, $q->getValue, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokPrefix')) {
+    return DDC::Any::CQFHasFieldPrefix->new($field, $q->getValue, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokSuffix')) {
+    return DDC::Any::CQFHasFieldSuffix->new($field, $q->getValue, $q->getNegated);
+  } elsif (UNIVERSAL::isa($q, 'DDC::Any::CQTokInfix')) {
+    return DDC::Any::CQFHasFieldInfix->new($field, $q->getValue, $q->getNegated);
   } else {
     $coldb->logconfess("can't handle metadata restriction of type ", ref($q), " in $logas request: \`", $q->toString, "'");
   }
@@ -2155,8 +2152,8 @@ sub parseGroupBy {
 
   ##-- groupby clause: date
   my $gbdate = ($opts{slice}<=0
-		? DDC::XS::CQCountKeyExprConstant->new($opts{slice}||'0')
-		: DDC::XS::CQCountKeyExprDateSlice->new('date',$opts{slice}));
+		? DDC::Any::CQCountKeyExprConstant->new($opts{slice}||'0')
+		: DDC::Any::CQCountKeyExprDateSlice->new('date',$opts{slice}));
 
   ##-- groupby clause: user request
   my $gbexprs   = [$gbdate];
@@ -2169,7 +2166,7 @@ sub parseGroupBy {
       or $coldb->logconfess($coldb->{error}="failed to parse DDC groupby request \`$req': $coldb->{error}");
     push(@$gbexprs, @{$gbq->getKeys->getExprs});
     $_->setMatchId($opts{matchid}//0)
-      foreach (grep {UNIVERSAL::isa($_,'DDC::XS::CQCountKeyExprToken') && !$_->HasMatchId} @$gbexprs);
+      foreach (grep {UNIVERSAL::isa($_,'DDC::Any::CQCountKeyExprToken') && !$_->HasMatchId} @$gbexprs);
   }
   else {
     ##-- native-style request with optional restrictions
@@ -2183,15 +2180,15 @@ sub parseGroupBy {
       }
       else {
 	##-- token attribute
-	if (defined($_->[1]) && !UNIVERSAL::isa($_->[1], 'DDC::XS::CQTokAny')) {
-	  $gbrestr = (defined($gbrestr) ? DDC::XS::CQWith->new($gbrestr,$_->[1]) : $_->[1]);
+	if (defined($_->[1]) && !UNIVERSAL::isa($_->[1], 'DDC::Any::CQTokAny')) {
+	  $gbrestr = (defined($gbrestr) ? DDC::Any::CQWith->new($gbrestr,$_->[1]) : $_->[1]);
 	}
       }
     }
   }
 
   ##-- finalize: expression list
-  my $xlist = DDC::XS::CQCountKeyExprList->new;
+  my $xlist = DDC::Any::CQCountKeyExprList->new;
   $xlist->setExprs($gbexprs);
 
   return ($xlist,$gbrestr,$gbfilters);
